@@ -179,7 +179,7 @@ unsigned int Kleo::classify(const QStringList &fileNames)
     return result;
 }
 
-static unsigned int classifyExtension(const QFileInfo fi)
+static unsigned int classifyExtension(const QFileInfo &fi)
 {
     const _classification *const it = qBinaryFind(std::begin(classifications), std::end(classifications),
                                       fi.suffix().toLatin1().constData(),
@@ -223,7 +223,7 @@ unsigned int Kleo::classify(const QString &filename)
     /* More reliable */
     const unsigned int contentClass = classifyContent(file.read(4096));
     if (contentClass != defaultClassification) {
-        qCDebug(LIBKLEO_LOG) << "Classified based on content.";
+        qCDebug(LIBKLEO_LOG) << "Classified based on content as:" << contentClass;
         return contentClass;
     }
 
