@@ -113,6 +113,7 @@ KLEO_EXPORT QString ownerTrustShort(GpgME::Key::OwnerTrust trust);
 KLEO_EXPORT QString validityShort(const GpgME::Subkey &subkey);
 KLEO_EXPORT QString validityShort(const GpgME::UserID &uid);
 KLEO_EXPORT QString validityShort(const GpgME::UserID::Signature &sig);
+KLEO_EXPORT QIcon   validityIcon(const GpgME::UserID::Signature &sig);
 /* A sentence about the validity of the UserID */
 KLEO_EXPORT QString validity(const GpgME::UserID &uid);
 
@@ -132,6 +133,24 @@ KLEO_EXPORT QString usageString(const GpgME::Subkey &subkey);
 KLEO_EXPORT QString summaryLine(const GpgME::Key &key);
 
 KLEO_EXPORT QIcon iconForUid(const GpgME::UserID &uid);
+
+/* Is the key valid i.e. are all uids fully trusted?  */
+KLEO_EXPORT bool uidsHaveFullValidity(const GpgME::Key &key);
+
+/* The compliance mode of the gnupg system. Empty if compliance
+ * mode is not set. */
+KLEO_EXPORT QString complianceMode();
+
+/* Is the given key in compliance with CO_DE_VS?  */
+KLEO_EXPORT bool isKeyDeVs(const GpgME::Key &key);
+
+/* A sentence if the key confirms to the current compliance mode */
+KLEO_EXPORT QString complianceStringForKey(const GpgME::Key &key);
+
+/* A single word for use in keylists to describe the validity of the
+ * given key, including any conformance statements relevant to the
+ * current conformance mode.  */
+KLEO_EXPORT QString complianceStringShort(const GpgME::Key &key);
 }
 }
 
